==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/kontact/plugins/karm/karm_plugin.h <==
/*
    This file is part of Kontact.

    Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>
    adapted for karm 2005 by Thorsten Staerk <kde@staerk.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef KARM_PLUGIN_H
#define KARM_PLUGIN_H

#include <klocale.h>
#include <kparts/part.h>

#include "plugin.h"

class OrgKdeKarmKarmInterface;

class KarmPlugin : public Kontact::Plugin
{
  Q_OBJECT

  public:
    KarmPlugin( Kontact::Core *core, const QStringList & );
    ~KarmPlugin();

    virtual QString tipFile() const;
    int weight() const { return 700; }

  protected:
    KParts::ReadOnlyPart *createPart();
    OrgKdeKarmKarmInterface *mInterface;

  public slots:
    void newTask();

};

#endif

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/kontact/plugins/karm/karm_plugin.h <==
/*
    This file is part of Kontact.

    Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>
    adapted for karm 2005 by Thorsten Staerk <kde@staerk.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef KARM_PLUGIN_H
#define KARM_PLUGIN_H

#include <klocale.h>
#include <kparts/part.h>

#include "plugin.h"

class OrgKdeKtimetrackerKtimetrackerInterface;

class KarmPlugin : public Kontact::Plugin
{
  Q_OBJECT

  public:
    KarmPlugin( Kontact::Core *core, const QStringList & );
    ~KarmPlugin();

    virtual QString tipFile() const;
    int weight() const { return 700; }

  protected:
    KParts::ReadOnlyPart *createPart();
    OrgKdeKtimetrackerKtimetrackerInterface *mInterface;

  public slots:
    void newTask();

};

#endif
